@@ -46,15 +46,17 @@ def _setup_args(parser: ArgumentParser) -> None:
     parser_mesh.add_argument("--get-parental-control", action="store_true", help="Retrieve Parental Control state")
     parser_mesh.add_argument("--get-guest-wifi-details", action="store_true", help="Retrieve guest Wi-Fi details")
     parser_mesh.add_argument("--get-latest-speedtest", action="store_true", help="Retrieve latest Speedtest results")
+    parser_mesh.add_argument("--get-available-storage", action="store_true", help="Retrieve external storage details")
+    parser_mesh.add_argument("--get-storage-settings", action="store_true", help="Retrieve external storage settings")
     # endregion
 
     # region #-- Node arguments --#
     parser_node = sub_parsers.add_parser("node", parents=[parser_shared], help="Interact with a node")
     parser_node.add_argument("-r", "--reboot", action="store_true", help="Reboot a node")
     parser_node.add_argument("name", help="The name of the node to interact with")
+    parser_node.add_argument("--get-backhaul", action="store_true", help="Retrieve backhaul details for the node")
     parser_node.add_argument("--get-overview", action="store_true", help="Retrieve high level details about the node")
     parser_node.add_argument("--get-network", action="store_true", help="Retrieve network details for the node")
-    parser_node.add_argument("--get-parent", action="store_true", help="Retrieve parent details for the node")
     parser_node.add_argument("--get-connected-devices", action="store_true", help="Retrieve connected devices")
     # endregion
 
@@ -159,6 +161,26 @@ async def main() -> None:
                     sections.append(section.rstrip("\n"))
                 # endregion
 
+                # region #-- get the storage server settings --#
+                if args.get_storage_settings or all_args:
+                    _LOGGER.debug("Preparing storage server settings")
+                    section = "Storage Settings"
+                    section += f"\n{'-' * len(section)}"
+                    for ss_k, ss_v in _mesh.storage_settings.items():
+                        section += f"\n{ss_k}: {ss_v}"
+                    sections.append(section)
+                # endregion
+
+                # region #-- get the storage server settings --#
+                if args.get_available_storage or all_args:
+                    _LOGGER.debug("Preparing available storage")
+                    section = "Available Storage"
+                    section += f"\n{'-' * len(section)}"
+                    for partition in _mesh.storage_available:
+                        section += f"\n{partition.get('label')}: {partition}"
+                    sections.append(section)
+                # endregion
+
                 # region #-- get the latest Speedtest results --#
                 if args.get_latest_speedtest or all_args:
                     _LOGGER.debug("Preparing latest Speedtest results")
@@ -240,7 +262,7 @@ async def main() -> None:
                                    f"Serial #: {_node.serial}\n"\
                                    f"Firmware: {_node.firmware.get('version')}\n"\
                                    f"Latest Firmware: {_node.firmware.get('latest_version')}\n" \
-                                   f"Last Update Check: {_node.last_update_check}\n"
+                                   f"Last Update Check: {_node.last_update_check}"
                         sections.append(section)
                     # endregion
 
@@ -255,12 +277,14 @@ async def main() -> None:
                         sections.append(section)
                     # endregion
 
-                    # region #-- get the parent details --#
-                    if args.get_parent or all_args:
-                        _LOGGER.debug("Preparing node parent details")
-                        section = "Parent"
+                    # region #-- backhaul details --#
+                    if args.get_backhaul or all_args:
+                        _LOGGER.debug("Preparing backhaul details")
+                        section = "Backhaul"
                         section += f"\n{'-' * len(section)}\n"
-                        section += f"{_node.parent_name} ({_node.parent_ip})"
+                        section += f"Parent: {_node.parent_name} ({_node.parent_ip})"
+                        for bh_k, bh_v in _node.backhaul.items():
+                            section += f"\n{bh_k}: {bh_v}"
                         sections.append(section)
                     # endregion
 
