@@ -5,7 +5,7 @@ from typing import List
 # region #-- generic details --#
 _PACKAGE_NAME = "pyvelop"
 _PACKAGE_AUTHOR = "uvjim"
-_PACKAGE_VERSION = "2022.2.1"
+_PACKAGE_VERSION = "2022.2.2"
 # endregion
 
 # region #-- JNAP actions --#
@@ -20,7 +20,9 @@ ACTION_JNAP_GET_GUEST_NETWORK_INFO: str = f"{ACTION_JNAP_ROOT}/guestnetwork/GetG
 ACTION_JNAP_GET_PARENTAL_CONTROL_INFO: str = f"{ACTION_JNAP_ROOT}/parentalcontrol/GetParentalControlSettings"
 ACTION_JNAP_GET_SPEEDTEST_RESULTS: str = f"{ACTION_JNAP_ROOT}/healthcheck/GetHealthCheckResults"
 ACTION_JNAP_GET_SPEEDTEST_STATE: str = f"{ACTION_JNAP_ROOT}/healthcheck/GetHealthCheckStatus"
+ACTION_JNAP_GET_STORAGE_PARTITIONS: str = f"{ACTION_JNAP_ROOT}/nodes/storage/GetNodesPartitions"
 # noinspection DuplicatedCode
+ACTION_JNAP_GET_STORAGE_SMB_SERVER: str = f"{ACTION_JNAP_ROOT}/nodes/storage/GetSMBServerSettings"
 ACTION_JNAP_GET_UPDATE_FIRMWARE_STATE: str = f"{ACTION_JNAP_ROOT}/nodes/firmwareupdate/GetFirmwareUpdateStatus"
 ACTION_JNAP_GET_WAN_INFO: str = f"{ACTION_JNAP_ROOT}/router/GetWANStatus3"
 ACTION_JNAP_REBOOT: str = f"{ACTION_JNAP_ROOT}/core/Reboot"
@@ -39,6 +41,7 @@ ATTR_MESH_NODES = "nodes"
 ATTR_MESH_PARENTAL_CONTROL_INFO = "parental_control"
 ATTR_MESH_SPEEDTEST_RESULTS = "speedtest_results"
 ATTR_MESH_SPEEDTEST_STATE = "speedtest_state"
+ATTR_MESH_STORAGE = "storage"
 ATTR_MESH_UPDATE_FIRMWARE_STATE = "check_update_state"
 ATTR_MESH_WAN_INFO = "wan_info"
 # endregion
